@@ -16,7 +16,6 @@
 
 #include <KLocalizedString>
 #include <KConfigGroup>
-#include <kconfigwidgets_version.h>
 
 #include <QDebug>
 #include <QDialogButtonBox>
@@ -90,11 +89,7 @@ void DlgSettingsWidget::slotNewEngine()
     DlgEngineEditing dialog;
     if(dialog.exec()) {
         addSearchEngineItem(dialog.engineName(), dialog.engineUrl());
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        Q_EMIT changed();
-#else
         Q_EMIT markAsChanged();
-#endif
     }
 }
 
@@ -104,11 +99,7 @@ void DlgSettingsWidget::slotRemoveEngine()
 
     foreach(QTreeWidgetItem * selectedItem, selectedItems)
         delete(selectedItem);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        Q_EMIT changed();
-#else
-        Q_EMIT markAsChanged();
-#endif
+    Q_EMIT markAsChanged();
 }
 
 void DlgSettingsWidget::load()
@@ -119,11 +110,7 @@ void DlgSettingsWidget::load()
 void DlgSettingsWidget::addSearchEngineItem(const QString &name, const QString &url)
 {
     ui.enginesTreeWidget->addTopLevelItem(new QTreeWidgetItem(QStringList() << name << url));
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        Q_EMIT changed();
-#else
-        Q_EMIT markAsChanged();
-#endif
+    Q_EMIT markAsChanged();
 }
 
 void DlgSettingsWidget::loadSearchEnginesSettings()
